Kolmogorov-Smirnov test for matrix normality: Kolmogorov-Smirnov test for matrix normality
Description
Kolmogorov-Smirnov test for matrix normality
Usage
ddkstest(X, M, U, V, alpha = 0.05)
Value
A message. If the Kronecker product covariance structure is not present, the message reads "Reject" and "Not reject otherwise".
Arguments
X
A list with k elements, k matrices of dimension \(n \ times p\) each. In the case of one matrix only, this may be given as a numerical matrix and not as an element in a list.
M
The mean matrix of the distribution, a numerical matrix of dimensions \(n \times p\).
U
The covariance matrix associated with the rows, a numerical matrix of dimensions \(n \times n\).
V
The covariance matrix associated with the columns, a numerical matrix of dimensions \(p \times p\).
alpha
The significance level for the test, set by default equal to 0.05.
Author
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Details
The Kolmogorov-Smirnov test for matrix normality is performed. See Pocuca (2019) for more details.
References
Pocuca N., Gallaugher M. P., Clark K. M. & McNicholas P. D. (2019). Assessing and Visualizing Matrix Variate Normality. arXiv:1910.02859.